AARE
==============================================

.. note :: 
    
    **Examples:**

    - `jupyter notebooks <https://github.com/slsdetectorgroup/aare-notebooks>`_
    - `cmake+install <https://github.com/slsdetectorgroup/aare-examples>`_
    - `git submodule <https://github.com/slsdetectorgroup/aare-submodule>`_




.. toctree::
    :caption: Installation
    :maxdepth: 3
    
    Installation
    Requirements
    Consume

.. toctree::
    :caption: Python API
    :maxdepth: 1
    
    pyFile
    pycalibration
    pyCtbRawFile
    pyClusterFile
    pyClusterVector
    pyJungfrauDataFile
    pyRawFile
    pyRawMasterFile
    pyVarClusterFinder

    pyFit


.. toctree::
    :caption: C++ API
    :maxdepth: 1
    
    algorithm
    NDArray
    NDView
    Frame
    File
    Dtype
    ClusterFinder
    ClusterFinderMT
    ClusterFile
    ClusterVector
    JungfrauDataFile
    Pedestal
    RawFile
    RawSubFile
    RawMasterFile
    VarClusterFinder



.. toctree::
    :caption: Developer
    :maxdepth: 3
    
    Philosophy
    Workflow
    Tests